==> qtsensors-opensource-src_5.12.8.orig.tar.xz: qtsensors-everywhere-src-5.12.8/src/plugins/sensors/simulator/simulatorproximitysensor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "simulatorproximitysensor.h"
#include <QDebug>
#include <QtGlobal>

const char *SimulatorProximitySensor::id("Simulator.ProximitySensor");

SimulatorProximitySensor::SimulatorProximitySensor(QSensor *sensor)
    : SimulatorCommon(sensor)
{
    setReading<QProximityReading>(&m_reading);
}

void SimulatorProximitySensor::poll()
{
    QtMobility::QProximityReadingData data = SensorsConnection::instance()->qtProximityData;
    quint64 newTimestamp;
    if (!data.timestamp.isValid())
        newTimestamp = QDateTime::currentMSecsSinceEpoch() / 1000;
    else
        newTimestamp = data.timestamp.toTime_t();
    if (m_reading.close() != data.close) {
            m_reading.setTimestamp(newTimestamp);
            m_reading.setClose(data.close);

            newReadingAvailable();
    }
}

==> qtsensors-opensource-src_5.15.17.orig.tar.xz: qtsensors-everywhere-src-5.15.17/src/plugins/sensors/simulator/simulatorproximitysensor.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "simulatorproximitysensor.h"
#include <QDebug>
#include <QtGlobal>

const char *SimulatorProximitySensor::id("Simulator.ProximitySensor");

SimulatorProximitySensor::SimulatorProximitySensor(QSensor *sensor)
    : SimulatorCommon(sensor)
{
    setReading<QProximityReading>(&m_reading);
}

void SimulatorProximitySensor::poll()
{
    QtMobility::QProximityReadingData data = SensorsConnection::instance()->qtProximityData;
    quint64 newTimestamp;
    if (!data.timestamp.isValid())
        newTimestamp = static_cast<quint64>(QDateTime::currentMSecsSinceEpoch() / 1000;
    else
        newTimestamp = static_cast<quint64>(data.timestamp.toSecsSinceEpoch();
    if (m_reading.close() != data.close) {
            m_reading.setTimestamp(newTimestamp);
            m_reading.setClose(data.close);

            newReadingAvailable();
    }
}
